#!/bin/sh
AWK=$1

echo "class LWSymbol;" > symbols.h

for i in command*.cc
do
    $AWK -f symbols.h.awk $i >> symbols.h
done

for i in variable*.cc
do
    $AWK -f symbols.h.awk $i >> symbols.h
done

for i in symbol*.cc
do
	if [ $i != symbols.cc ] ; then
	    $AWK -f symbols.h.awk $i >> symbols.h
	fi
done
